/*****************************************************************************
 * Copyright (C) 2014
 *   
 * Michiel Broek <mbroek at mbse dot eu>
 *
 * This file is part of the mbsePi-apps
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2, or (at your option) any
 * later version.
 *
 * mbsePi-apps is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with ThermFerm; see the file COPYING.  If not, write to the Free
 * Software Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *****************************************************************************/

#include "logger.h"
#include "thermferm.h"
#include "futil.h"
#include "xutil.h"


void initlog(char *unit)
{
    char	buf[128], *filename;

    snprintf(buf, 127, "Mode,Air,Beer,Target,Heater,Cooler,Fan,Door");
    filename = xstrcpy(unit);
    filename = xstrcat(filename, (char *)".log");
    logger(filename, buf);
    free(filename);
    filename = NULL;
}



void logger(char *filename, char *data)
{
    struct timeval	now;
    struct tm		ptm;
    char		*outstr = NULL, *name = NULL;
    FILE		*logfile;

    if (getenv((char *)"USER") == NULL) {
	name = xstrcpy((char *)"/root");
    } else {
	name = xstrcpy(getenv((char *)"HOME"));
    }
    name = xstrcat(name, (char *)"/.thermferm/log/");
    mkdirs(name, 0755);
    name = xstrcat(name, filename);

    gettimeofday(&now, NULL);
    localtime_r(&now.tv_sec, &ptm);
    outstr = calloc(10240, sizeof(char));
    snprintf(outstr, 10239, "%04d-%02d-%02d %02d:%02d,%s\n", ptm.tm_year + 1900, ptm.tm_mon + 1, ptm.tm_mday, ptm.tm_hour, ptm.tm_min, data);

    if ((logfile = fopen(name, "a+"))) {
	fprintf(logfile, outstr);
	fclose(logfile);
    } else {
	syslog(LOG_NOTICE, "logger: cannot open %s for writing", name);
    }

    free(outstr);
    outstr = NULL;
    free(name);
    name = NULL;
}


